@@ -20,7 +20,9 @@ enum {
 	PROP_N_SLOTS,
 	PROP_SLOT_DURATION,
 	PROP_SLOT_SIZE,
-	PROP_LINE_EVERY_NTH_SLOT
+	PROP_LINE_EVERY_NTH_SLOT,
+	PROP_DISABLED_SLOTS_BEGIN,
+	PROP_DISABLED_SLOTS_END
 };
 
 struct _JammoTrackViewPrivate {
@@ -29,8 +31,13 @@ struct _JammoTrackViewPrivate {
 	guint64 slot_duration;
 	gfloat slot_size;
 	guint line_every_nth_slot;
+	guint disabled_slots_begin;
+	guint disabled_slots_end;
+	ClutterColor hilight_color;
 	
 	gfloat real_slot_size;
+	gfloat hilighted_start;
+	gfloat hilighted_end;
 };
 
 static void on_actor_added(TangleWidget* widget, ClutterActor* actor, gpointer user_data);
@@ -61,8 +68,44 @@ guint jammo_track_view_get_sample_button_slot(JammoTrackView* track_view, JammoS
 }
 
 static gboolean jammo_track_view_is_dragging_droppable(TangleDroppableActor* droppable_actor, TangleDragging* dragging) {
+	gboolean droppable = FALSE;
+	JammoTrackView* track_view;
+	gfloat center_x, center_y;
+	guint slot;
+	guint n_slots;
+	gfloat start;
 	
-	return JAMMO_IS_SAMPLE_BUTTON(dragging->draggable_actor);
+	track_view = JAMMO_TRACK_VIEW(droppable_actor);
+	
+	if (JAMMO_IS_SAMPLE_BUTTON(dragging->draggable_actor) &&
+	    clutter_actor_transform_stage_point(CLUTTER_ACTOR(track_view), dragging->center_x, dragging->center_y, &center_x, &center_y)) {
+		n_slots = (guint)(clutter_actor_get_width(CLUTTER_ACTOR(dragging->draggable_actor)) / track_view->priv->real_slot_size + 0.5);
+		center_x -= (n_slots - 1) * track_view->priv->real_slot_size / 2;
+		slot = center_x / track_view->priv->real_slot_size;
+
+		if (slot >= track_view->priv->disabled_slots_begin &&
+		    slot + n_slots - 1 < track_view->priv->n_slots - track_view->priv->disabled_slots_end) {
+			droppable = TRUE;
+			start = slot * track_view->priv->real_slot_size;
+			if (start != track_view->priv->hilighted_start) {
+				track_view->priv->hilighted_start = start;
+				track_view->priv->hilighted_end = start + n_slots * track_view->priv->real_slot_size;
+				clutter_actor_queue_redraw(CLUTTER_ACTOR(track_view));
+			}
+		}
+	}
+	
+	if (!droppable && track_view->priv->hilighted_start != track_view->priv->hilighted_end) {
+		track_view->priv->hilighted_start = track_view->priv->hilighted_end = 0.0;
+		clutter_actor_queue_redraw(CLUTTER_ACTOR(track_view));
+	}
+	    		
+	return droppable;
+}
+
+static gboolean jammo_track_view_handle_dragging(TangleDroppableActor* droppable_actor, TangleDragging* dragging) {
+
+	return FALSE;
 }
 
 static void jammo_track_view_get_preferred_width(TangleActor* actor, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p) {
@@ -118,6 +161,7 @@ static gboolean jammo_track_view_handle_dropping(TangleDroppableActor* droppable
 	JammoSampleButton* sample_button;
 	ClutterActor* copy_of_sample_button;
 	guint slot;
+	guint n_slots;
 	
 	track_view = JAMMO_TRACK_VIEW(droppable_actor);
 	widget = TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(track_view)));
@@ -129,6 +173,8 @@ static gboolean jammo_track_view_handle_dropping(TangleDroppableActor* droppable
 		sample_button = JAMMO_SAMPLE_BUTTON(dragging->draggable_actor);
 		copy_of_sample_button = jammo_sample_button_new_from_existing(sample_button);
 
+		n_slots = (guint)(clutter_actor_get_width(CLUTTER_ACTOR(dragging->draggable_actor)) / track_view->priv->real_slot_size + 0.5);
+		center_x -= (n_slots - 1) * track_view->priv->real_slot_size / 2;
 		slot = center_x / track_view->priv->real_slot_size;
 
 		jammo_editing_track_add_sample(track_view->priv->track, jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(copy_of_sample_button)), slot * track_view->priv->slot_duration);
@@ -142,10 +188,43 @@ static gboolean jammo_track_view_handle_dropping(TangleDroppableActor* droppable
 
 		move_others_right_if_overlapping(track_view, copy_of_sample_button, slot);
 	}
+	
+	track_view->priv->hilighted_start = track_view->priv->hilighted_end = 0.0;
 
 	return FALSE;
 }
 
+static void jammo_track_view_paint(ClutterActor* actor) {
+	JammoTrackView* track_view;
+	gdouble scale_x;
+	gdouble scale_y;
+	guint8 alpha;
+	ClutterActorBox box;
+
+	track_view = JAMMO_TRACK_VIEW(actor);
+
+	if (CLUTTER_ACTOR_IS_MAPPED(actor)) {
+		CLUTTER_ACTOR_CLASS(jammo_track_view_parent_class)->paint(actor);
+
+		if (track_view->priv->hilighted_start != track_view->priv->hilighted_end) {
+			cogl_push_matrix();
+
+			g_object_get(actor, "transition-scale-x", &scale_x, "transition-scale-y", &scale_y, NULL);
+			cogl_scale(scale_x, scale_y, 0);
+
+			alpha = clutter_actor_get_paint_opacity(actor) * track_view->priv->hilight_color.alpha / 255;
+			cogl_set_source_color4ub(track_view->priv->hilight_color.red,
+			 			 track_view->priv->hilight_color.green,
+			 			 track_view->priv->hilight_color.blue,
+						 alpha);
+			tangle_actor_get_aligned_allocation(TANGLE_ACTOR(actor), &box);
+			cogl_rectangle(box.x1 + track_view->priv->hilighted_start, box.y1, box.x1 + track_view->priv->hilighted_end, box.y2);
+
+			cogl_pop_matrix();
+		}
+	}
+}
+
 static GObject* jammo_track_view_constructor(GType type, guint n_construct_properties, GObjectConstructParam* construct_properties) {
 	GObject* object;
 	JammoTrack* track;
@@ -188,6 +267,12 @@ static void jammo_track_view_set_property(GObject* object, guint prop_id, const
 			track_view->priv->line_every_nth_slot = g_value_get_uint(value);
 			clutter_actor_queue_relayout(CLUTTER_ACTOR(track_view));
 			break;
+		case PROP_DISABLED_SLOTS_BEGIN:
+			track_view->priv->disabled_slots_begin = g_value_get_uint(value);
+			break;
+		case PROP_DISABLED_SLOTS_END:
+			track_view->priv->disabled_slots_end = g_value_get_uint(value);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -215,6 +300,12 @@ static void jammo_track_view_get_property(GObject* object, guint prop_id, GValue
 		case PROP_LINE_EVERY_NTH_SLOT:
 			g_value_set_uint(value, track_view->priv->line_every_nth_slot);
 			break;
+		case PROP_DISABLED_SLOTS_BEGIN:
+			g_value_set_uint(value, track_view->priv->disabled_slots_begin);
+			break;
+		case PROP_DISABLED_SLOTS_END:
+			g_value_set_uint(value, track_view->priv->disabled_slots_end);
+			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -231,6 +322,7 @@ static void jammo_track_view_dispose(GObject* object) {
 
 static void jammo_track_view_class_init(JammoTrackViewClass* track_view_class) {
 	GObjectClass* gobject_class = G_OBJECT_CLASS(track_view_class);
+	ClutterActorClass* clutter_actor_class = CLUTTER_ACTOR_CLASS(track_view_class);
 	TangleActorClass* actor_class = TANGLE_ACTOR_CLASS(track_view_class);
 	TangleWrapperActorClass* wrapper_actor_class = TANGLE_WRAPPER_ACTOR_CLASS(track_view_class);
 	TangleDroppableActorClass* droppable_actor_class = TANGLE_DROPPABLE_ACTOR_CLASS(track_view_class);
@@ -241,12 +333,15 @@ static void jammo_track_view_class_init(JammoTrackViewClass* track_view_class) {
 	gobject_class->set_property = jammo_track_view_set_property;
 	gobject_class->get_property = jammo_track_view_get_property;
 	
+	clutter_actor_class->paint = jammo_track_view_paint;
+	
 	actor_class->get_preferred_width = jammo_track_view_get_preferred_width;
 	actor_class->get_preferred_height = jammo_track_view_get_preferred_height;
 	
 	wrapper_actor_class->allocate_wrapped = jammo_track_view_allocate_wrapped;
 	
 	droppable_actor_class->is_dragging_droppable = jammo_track_view_is_dragging_droppable;
+	droppable_actor_class->handle_dragging = jammo_track_view_handle_dragging;
 	droppable_actor_class->handle_dropping = jammo_track_view_handle_dropping;
 
 	/**
@@ -304,12 +399,39 @@ static void jammo_track_view_class_init(JammoTrackViewClass* track_view_class) {
 	                                "The number of slots after a separator line is drawn (0 to disable)",
 	                                0, G_MAXUINT, 0,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoTrackView:disabled-slots-begin:
+	 *
+	 * The number of slots that are disabled (in terms of dropping) from the beginning of the track.
+	 */
+	g_object_class_install_property(gobject_class, PROP_DISABLED_SLOTS_BEGIN,
+	                                g_param_spec_uint("disabled-slots-begin",
+	                                "Disabled slots begin",
+	                                "The number of slots that are disabled (in terms of dropping) from the beginning of the track",
+	                                0, G_MAXUINT, 0,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoTrackView:disabled-slots-end:
+	 *
+	 * The number of slots that are disabled (in terms of dropping) from the end of the track.
+	 */
+	g_object_class_install_property(gobject_class, PROP_DISABLED_SLOTS_END,
+	                                g_param_spec_uint("disabled-slots-end",
+	                                "Disabled slots end",
+	                                "The number of slots that are disabled (in terms of dropping) from the end of the track",
+	                                0, G_MAXUINT, 0,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private (gobject_class, sizeof (JammoTrackViewPrivate));
 }
 
 static void jammo_track_view_init(JammoTrackView* track_view) {
 	track_view->priv = G_TYPE_INSTANCE_GET_PRIVATE(track_view, JAMMO_TYPE_TRACK_VIEW, JammoTrackViewPrivate);
+
+	track_view->priv->hilight_color.red = 255;
+	track_view->priv->hilight_color.green = 255;
+	track_view->priv->hilight_color.blue = 255;
+	track_view->priv->hilight_color.alpha = 100;
 }
 
 static void on_actor_added(TangleWidget* widget, ClutterActor* actor, gpointer user_data) {
@@ -387,3 +509,4 @@ static void move_others_right_if_overlapping(JammoTrackView* track_view, Clutter
 		}
 	}
 }
+
