@@ -18,8 +18,12 @@
 
 #include "../meam/jammo-recording-track.h"
 #include "jammo-mentor.h"
+#include "../meam/jammo-playing-track.h"
+
+JammoRecordingTrack* recording_track;
+
+static JammoSequencer* sequencer;
 
-extern JammoRecordingTrack* recording_track;
 
 ClutterActor *contour_cursor;
 ClutterActor *contour_trace;
@@ -102,7 +106,7 @@ static void on_pitch_detected(JammoRecordingTrack* track, gfloat frequency, gpoi
 
 static void singingame_start_sequencer(JammoMentor* mentor, const gchar* speech, gpointer user_data){
 tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
-chum_play_sequencer();
+jammo_sequencer_play(sequencer);
 }
 
 
@@ -127,7 +131,57 @@ void singinggame_song_click(TangleAction *action, GObject *source, const gchar *
 	const gchar* name = clutter_actor_get_name(ct);
 	printf("Song clicked. get_name: '%s'\n",name);
 
-	chum_change_to_song(name);
+	const char *song_name=name;
+	
+	chum_set_current_song(song_name);
+	
+	if (sequencer) {
+		g_object_unref(sequencer);
+	}
+	sequencer = jammo_sequencer_new();
+
+	gchar *filename;
+	int fd;
+	if (chum_get_duetto())
+		{
+		filename = g_strdup_printf("%s/songs/%s/vocal%s.ogg", DATA_DIR,song_name,chum_get_selected_language());
+		fd = open(filename,O_RDONLY);
+		if (fd == -1) //File not found
+			{  //no vocal track. use only comping.
+			filename = g_strdup_printf("%s/songs/%s/comping.ogg", DATA_DIR,song_name); //try without language postfix
+			}
+		}
+	else //solo
+	{
+	filename = g_strdup_printf("%s/songs/%s/comping%s.ogg", DATA_DIR,song_name,chum_get_selected_language());
+	fd = open(filename,O_RDONLY);
+			if (fd == -1) //File not found
+			{  //no track for this language,. use  common comping.
+			filename = g_strdup_printf("%s/songs/%s/comping.ogg", DATA_DIR,song_name); //try without language postfix
+			}
+	}
+
+
+	JammoPlayingTrack* playing_track;
+	printf("looking for file '%s' \n",filename);
+	playing_track = jammo_playing_track_new(filename);   //for comping track
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(playing_track));
+
+	gchar* recording_filename = g_strdup_printf("%s/last_recorded.wav",JAMMO_DIRECTORY);
+	//Do not use pitch_detect on OFFICIAL_RELEASE (not robust enough)
+	#ifdef OFFICIAL_RELEASE
+	recording_track = jammo_recording_track_new(recording_filename);
+	#else
+	recording_track = jammo_recording_track_new_with_pitch_detect(recording_filename);
+	#endif
+	g_free(recording_filename);
+
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(recording_track));
+
+	chum_set_state_of_chum(SCREEN_SONG_RECORDING);
+	g_free(filename);
+
+
 
 	gchar* name_of_view;
 	name_of_view = g_strdup_printf("song-%s-view", name );
@@ -145,7 +199,7 @@ void singinggame_song_click(TangleAction *action, GObject *source, const gchar *
 	//contour_cursor = moving thing
 	contour_cursor = clutter_texture_new();
 	filepath1 = g_strdup_printf("%s/songs/%s/cursor%s.png", DATA_DIR, name, selected_language );
-	int fd = open(filepath1,O_RDONLY);
+	fd = open(filepath1,O_RDONLY);
 	if (fd == -1) //File not found
 		{
 		filepath1 = g_strdup_printf("%s/songs/%s/cursor.png", DATA_DIR,name ); //try without language postfix
@@ -219,15 +273,50 @@ void singinggame_cross_click(TangleAction *action, GObject *source, const gchar
 		#endif
 
 
-		chum_play_recorded_and_backing_track(); 
+		JammoSample* sample1;
+		JammoSample* sample2;
+		JammoEditingTrack* backing_track;
+		JammoEditingTrack* recorded_track;
+
+
+		if (sequencer) {
+			jammo_sequencer_stop(sequencer);
+			g_object_unref(sequencer);
+		}
+		sequencer = jammo_sequencer_new();
+
+		backing_track = jammo_editing_track_new();
+		jammo_sequencer_add_track(sequencer, JAMMO_TRACK(backing_track));
+
+		gchar *filename = g_strdup_printf("%s/songs/%s/comping%s.ogg", DATA_DIR,chum_get_current_song(),chum_get_selected_language());
+		int fd = open(filename,O_RDONLY);
+		if (fd == -1) //File not found
+			{
+			filename = g_strdup_printf("%s/songs/%s/comping.ogg", DATA_DIR,chum_get_current_song()); //use without language postfix
+			}
+		sample1 = jammo_sample_new_from_file(filename);
+		jammo_editing_track_add_sample(backing_track, sample1, 0);
+		g_free(filename);
+
+
+		//for recorded singing
+		recorded_track = jammo_editing_track_new(); 
+		jammo_sequencer_add_track(sequencer, JAMMO_TRACK(recorded_track));
+		gchar* filename2 = g_strdup_printf("%s/last_recorded.wav",JAMMO_DIRECTORY);
+		sample2 = jammo_sample_new_from_file(filename2);
+		g_free(filename2);
+
+		jammo_editing_track_add_sample(recorded_track, sample2, 0);
+		chum_set_state_of_chum(SCREEN_PLAY_RECORDED);
+
 		jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_welldone_fi.ogg", singingame_start_sequencer, NULL);
 		}
 
 	else if (chum_get_state_of_chum()==SCREEN_PLAY_RECORDED	)
 		{
-		printf("chum_get_state_of_chum()==SCREEN_PLAY_RECORDED");
+		printf("chum_get_state_of_chum()==SCREEN_PLAY_RECORDED\n");
 		jammo_mentor_shut_up(jammo_mentor_get_default());
-		chum_stop_sequencer();
+		jammo_sequencer_stop(sequencer);
 
 		//'actor' is pressed button, and it's parent is song-*-view
 		//Hide it
@@ -262,6 +351,24 @@ void singinggame_cross_click(TangleAction *action, GObject *source, const gchar
 
 		g_free(cmd);
 		}
+	else if (chum_get_state_of_chum()==SCREEN_FROM_CUPBOARD	)
+		{
+		printf("chum_get_state_of_chum()==SCREEN_FROM_CUPBOARD\n");
+
+		//Show mentor again
+		tangle_actor_show(TANGLE_ACTOR(jammo_mentor_get_default()));
+
+		//Hide all other views
+		ClutterActor* mainview;
+		mainview = jammo_get_actor_by_id("main-views-widget"); //No drawing on stage anymore, use this.
+		clutter_container_foreach(CLUTTER_CONTAINER(mainview), tangle_actor_hide_animated, NULL);
+
+		//Go to cupboard
+		gchar *new_name = g_strdup_printf("cupboard-view");
+		ClutterActor* new_view;
+		new_view = jammo_get_actor_by_id(new_name);	
+		clutter_actor_show(new_view);
+		}
 
 	else printf("Singinggame_cross_click: Error\n");
 }
