@@ -6,10 +6,10 @@
 #include "string.h"
 #include <fcntl.h> //we check some files
 #include "jammo-mentor.h"
+#include <math.h> //sin
 
 
-
-
+static JammoSequencer* composing_sequencer;
 static JammoTrackView* bottom_track_view;
 
 
@@ -134,20 +134,34 @@ static void asking_for_saving(ClutterActor* view, gpointer data){
 	
 	clutter_container_add(CLUTTER_CONTAINER(view),container_for_asking, NULL);
 }
+
 /*
 This is called when user click 'cross' / 'back_to_theme_selection'
 Give view to hide as parameter.
-
-
-TODO: ASK FOR SAVING. Now it saves automatically.
 */
 static void back_to_theme_selection_clicked (ClutterTexture *actor, ClutterEvent *event, gpointer data){
-	chum_stop_sequencer();
+	jammo_sequencer_stop(composing_sequencer);
 	asking_for_saving(CLUTTER_ACTOR(clutter_actor_get_parent(CLUTTER_ACTOR(actor))),data);
 }
 
 
 
+static gdouble phasing(gdouble start_value, int phase) {
+	gdouble value = start_value;
+	value += phase/100.0;
+	if (value>=1) value -= 1;
+	return value;
+}
+
+/*
+clutter_timeline_get_progress returns value between [0,1]
+with phasing we can shift it always same amount
+*/
+static gdouble sine_wave (ClutterAlpha *alpha,gpointer user_data) {
+return sin (phasing(clutter_timeline_get_progress (clutter_alpha_get_timeline (alpha)),GPOINTER_TO_INT(user_data)) * G_PI);
+}
+
+
 
 
 /*
@@ -159,7 +173,25 @@ static ClutterActor* create_samplebutton(gchar* themename, gchar* variation, gch
 	gchar *full_image = g_strdup_printf("%s/themes/%s/%s/%s",DATA_DIR,themename,variation,imagefile);
 	//printf("image file: '%s'\n",full_image);
 	gchar *full_sound = g_strdup_printf("%s/themes/%s/%s/%s",DATA_DIR,themename,variation,soundfile);
+	//printf("sound file: '%s'\n",full_sound);
 	sample_button = jammo_sample_button_new_from_files(full_image, full_sound);
+
+	//Each animation has own phase
+	int phase = (rand () % 100) + 1;
+	printf("phase %d\n",phase);
+	
+	//Each animation has own wobbling 'mode'-function
+	gulong sine_function;
+	sine_function = clutter_alpha_register_func (sine_wave, GINT_TO_POINTER(phase));
+	
+	ClutterAnimation* animation;
+	animation = clutter_actor_animate (sample_button, 
+            sine_function, 5000+phase*20, //each has own rhythm (we can use same random number, because phase is not visible on user in anyway. 
+            "opacity", 100,  //do not make it too transparency (0=transparency, 255=opaque)
+            "scale-y", 0.9,  //add some vertical scaling, this looks movement, but doesn't 
+            NULL);
+	clutter_animation_set_loop (animation,TRUE);
+	
 	g_free(full_image);
 	g_free(full_sound);
 	clutter_actor_set_position(sample_button, x, y);
@@ -179,16 +211,16 @@ static void menu_clicked(ClutterTexture *actor, ClutterEvent *event, gpointer us
 	//check if this menu is clicked already (is it visible)
 	
 	if (CLUTTER_ACTOR_IS_VISIBLE(CLUTTER_ACTOR(user_data))) {
-		printf("hiding\n");
+		//printf("hiding\n");
 		tangle_actor_hide_animated(TANGLE_ACTOR(user_data));
 	}
 	else {
 		int i;
-		for (i=0;i<3;i++)
+		for (i=0;i<4;i++)
 			{
 			tangle_actor_hide_animated(TANGLE_ACTOR(soundfamily[i]));
 			}
-		printf("showing\n");
+		//printf("showing\n");
 		tangle_actor_show(TANGLE_ACTOR(user_data));
 	}
 }
@@ -196,7 +228,8 @@ static gboolean on_play_button_clicked(ClutterActor* play_button, ClutterEvent *
 
 static gboolean on_stop_button_clicked(ClutterActor* play_button, ClutterEvent *event, gpointer user_data) {
 	printf("Play button pressed (stop)\n");
-	chum_stop_sequencer();
+	
+	jammo_sequencer_stop(JAMMO_SEQUENCER(user_data));
 	tangle_actor_show(TANGLE_ACTOR(jammo_mentor_get_default()));
 
 	//Change button to play
@@ -206,7 +239,7 @@ static gboolean on_stop_button_clicked(ClutterActor* play_button, ClutterEvent *
 	g_object_set(play_button, "x", 0.0,  "y", 195.0, NULL);
 	clutter_container_add(CLUTTER_CONTAINER(view), play_button, NULL);
 	clutter_actor_set_reactive(play_button,TRUE);
-	g_signal_connect (play_button, "button-press-event", G_CALLBACK (on_play_button_clicked),NULL);
+	g_signal_connect (play_button, "button-press-event", G_CALLBACK (on_play_button_clicked),user_data);
 
 	return FALSE;
 }
@@ -215,7 +248,9 @@ static gboolean on_stop_button_clicked(ClutterActor* play_button, ClutterEvent *
 static gboolean on_play_button_clicked(ClutterActor* play_button, ClutterEvent *event, gpointer user_data) {
 	printf("Play button pressed (play)\n");
 	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
-	chum_play_sequencer();
+	
+	
+	jammo_sequencer_play(JAMMO_SEQUENCER(user_data));
 
 	//Change button to stop
 	ClutterActor* view = clutter_actor_get_parent(play_button);
@@ -224,7 +259,7 @@ static gboolean on_play_button_clicked(ClutterActor* play_button, ClutterEvent *
 	g_object_set(play_button, "x", 0.0,  "y", 195.0, NULL);
 	clutter_container_add(CLUTTER_CONTAINER(view), play_button, NULL);
 	clutter_actor_set_reactive(play_button,TRUE);
-	g_signal_connect (play_button, "button-press-event", G_CALLBACK (on_stop_button_clicked),NULL);
+	g_signal_connect (play_button, "button-press-event", G_CALLBACK (on_stop_button_clicked),user_data);
 
 	return FALSE;
 }
@@ -303,10 +338,10 @@ gboolean themeselection_load(gchar* inputFilename) {
 /*
 Make colored rectangles and add them to given parent.
 Returns number of used slots (length of color_coding).
+white=# because it has special meaning. Samples can't be dropped on this slot. (TODO)
 */
 static int create_backing_track_color_coding(gchar* color_coding, gfloat slot_size, gfloat y_offset,TangleWidget* parent) {
 	ClutterActor* actor;
-	ClutterColor* black  = clutter_color_new(0,0,0,         255);
 	ClutterColor* white  = clutter_color_new(255,255,255,   255);
 	ClutterColor* yellow = clutter_color_new(255, 255, 0,   255);
 	ClutterColor* green  = clutter_color_new(0, 255, 0,     255);
@@ -325,8 +360,7 @@ static int create_backing_track_color_coding(gchar* color_coding, gfloat slot_si
 		ClutterColor* color;
 		switch (color_coding[i])
 			{
-			case '#': color =  black         ;break;
-			case 'w': color =  white         ;break;
+			case '#': color =  white         ;break;
 			case 'y': color =  yellow        ;break;
 			case 'g': color =  green         ;break;
 			case 'o': color =  orange        ;break;
@@ -345,6 +379,22 @@ static int create_backing_track_color_coding(gchar* color_coding, gfloat slot_si
 	return max;
 }
 
+
+static ClutterActor* create_soundfamily_button(const gchar* theme_name, const gchar* button_name, gfloat x, gfloat y,TangleWidget* parent){
+	ClutterActor* widget = tangle_widget_new();
+	clutter_container_add(CLUTTER_CONTAINER(parent), widget, NULL);
+	ClutterActor *menu;
+	gchar* filename = g_strdup_printf("%s/%s/advanced/%s", THEMES_DIR, theme_name,button_name);
+	menu=clutter_texture_new_from_file(filename, NULL);
+	g_object_set(menu, "x",x, "y", y, NULL);
+	clutter_container_add(CLUTTER_CONTAINER(parent), menu, NULL);
+	clutter_actor_set_reactive(menu,TRUE);
+	g_signal_connect (menu, "button-press-event", G_CALLBACK (menu_clicked),widget);
+	clutter_actor_hide(widget);
+	g_free(filename);
+	return widget;
+}
+
 #define WIDTH_OF_SLOT 40.0
 void themeselection_start_theme(const gchar* name){
 	printf("Theme '%s' starting.\n",name);
@@ -400,6 +450,9 @@ void themeselection_start_theme(const gchar* name){
 	gchar* background_color_code = "some_default";
 	gchar* backing_track_filepath = "no_any_backing_track";
 	
+	int disabled_slots_for_begin = 0;
+	int disabled_slots_for_end = 0;
+	
 	//Advanced game sets this to TRUE
 	gboolean use_two_tracks=FALSE;
 
@@ -416,6 +469,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("fantasy","140","witch.png",   "castle_140_melody_2.wav",       545.0,  31.0,TANGLE_WIDGET(view));
 	
 	background_color_code = "#yyyyyyyyppppppppyyyyyyyypppppppp###";
+	disabled_slots_for_begin = 1;
+	disabled_slots_for_end = 3;
 	}
 	else if (strncmp(name,"fantasy",7)==0 && variation==2){
 	create_samplebutton("fantasy","110","dragon.png","castle_110_clarinet_4.wav",      221.0,  39.0,TANGLE_WIDGET(view));
@@ -425,7 +480,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("fantasy","110","owl.png",   "castle_110_owl_2.wav",           627.0, 158.0,TANGLE_WIDGET(view));
 	create_samplebutton("fantasy","110","wolf.png",  "castle_110_wolf_4.wav",           21.0, 204.0,TANGLE_WIDGET(view));
 	
-	background_color_code = "bbbbbbbbbbbbbbbbrrrrrrrrvvvvvvvvbbbb##";
+	background_color_code = "bbbbbbbbbbbbbbbbrrrrrrrrvvvvvvvbbbbbbbb##";
+	disabled_slots_for_end = 2;
 	}
   else if (strncmp(name,"fantasy",7)==0 && variation==3){
 	create_samplebutton("fantasy","90", "bird.png",    "castle_90_whistle_4.wav",    611.0,  76.0,TANGLE_WIDGET(view));
@@ -446,7 +502,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("city","140","kids.png",       "city_140_yell_claps_2.wav",  689.0, 185.0,TANGLE_WIDGET(view));
 	create_samplebutton("city","140","motorcycle.png", "city_140_guitar2_2.wav",     306.0, 205.0,TANGLE_WIDGET(view));
 	
-	background_color_code = "yyyyyyyywwyyyyyyyywwgggggggwyyyyyyyy##";
+	background_color_code = "yyyyyyyybbyyyyyyyybbgggggggbyyyyyyyy##";
+	disabled_slots_for_end = 2;
 	}
   else if (strncmp(name,"city",4)==0 && variation==2){
 	create_samplebutton("city","110",  "beatbox.png", "city_110_beatbox_1.wav",       594.0, 169.0,TANGLE_WIDGET(view));
@@ -457,6 +514,7 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("city","110",  "zeppelin.png","city_110_bass_strings_2.wav",  299.0,   0.0,TANGLE_WIDGET(view));
 	
 	background_color_code = "bbbbbbbbrrrrbbbbrrrrbbbb##";
+	disabled_slots_for_end = 2;
 	}
 	else if (strncmp(name,"city",4)==0 && variation==3){
 	create_samplebutton("city","90",  "car.png",         "city_90_bass_shaker_2.wav",  286.0, 183.0,TANGLE_WIDGET(view));
@@ -467,6 +525,7 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("city","90",  "ufo.png",         "city_90_fx_2.wav",           264.0,  11.0,TANGLE_WIDGET(view));
 	
 	background_color_code = "ggggggggyyyyllllgggggggg##";
+	disabled_slots_for_end = 2;
 	}
 
 	else if (strncmp(name,"animal",6)==0 && variation==1){
@@ -488,6 +547,7 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("animal","110",  "spider.png",      "animalw_110_pluck_2.wav",       617.0, 222.0,TANGLE_WIDGET(view));
 	
 	background_color_code = "ggggggggbbbbbbbbgggggggg#";
+	disabled_slots_for_end = 1;
 	}
 	else if (strncmp(name,"animal",6)==0 && variation==3){
 	create_samplebutton("animal","90",  "bluebird.png",  "animalw_90_accordion2_2.wav",      533.0,  68.0,TANGLE_WIDGET(view));
@@ -498,107 +558,185 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("animal","90",  "monkey.png"    ,"animalw_90_percussion_2.wav",      328.0,  30.0,TANGLE_WIDGET(view));
 	
 	background_color_code = "yyyyyyyyggggggggoooooooo##";
+	disabled_slots_for_end = 2;
 	}
 
 	} //easy game
 
 
+
+
+
 else { //advanced
-	//There are some numbers of icons popping up menus with samplebuttons.
-	//These samplebuttons are just copy-pasted from easy. TODO.
-	//First
+	//Make buttons and containers for samplebuttons.
+	soundfamily[0] = create_soundfamily_button(name,"rhythmic_icon.png", 296.0, 103.0,TANGLE_WIDGET(view));
+	soundfamily[1] = create_soundfamily_button(name,"melodic_icon.png",  101.0, 164.0,TANGLE_WIDGET(view));
+	soundfamily[2] = create_soundfamily_button(name,"harmonic_icon.png", 631.0, 203.0,TANGLE_WIDGET(view));
+	soundfamily[3] = create_soundfamily_button(name,"effect_icon.png",   548.0,  26.0,TANGLE_WIDGET(view));
+
+	if (strncmp(name,"fantasy",7)==0){
+	//Rhythmic loops
+	create_samplebutton( "fantasy","advanced","donkey_1.png",  "Rh_90__34_1_shaker2.wav",   216.0,  20.0,TANGLE_WIDGET(soundfamily[0]));
+	create_samplebutton( "fantasy","advanced","donkey_2.png",  "Rh_90__34_2_bassdrum.wav",  296.0,  20.0,TANGLE_WIDGET(soundfamily[0])); 
+	create_samplebutton( "fantasy","advanced","donkey_3.png",  "Rh_90__34_1_triangle.wav",  216.0, 103.0,TANGLE_WIDGET(soundfamily[0]));
+	create_samplebutton( "fantasy","advanced","donkey_4.png",  "Rh_90__34_1_cajon.wav",     396.0,  20.0,TANGLE_WIDGET(soundfamily[0]));
+	create_samplebutton( "fantasy","advanced","donkey_5.png",  "Rh_90__34_1_shaker.wav",    396.0, 103.0,TANGLE_WIDGET(soundfamily[0]));
+
+	//Melodic loops
+	create_samplebutton("fantasy","advanced","potion_1.png",  "Me_90_F_34_1_piano.wav",        120.0, 80.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("fantasy","advanced","potion_2.png",  "Me_90_D_34_1_synth.wav",        51.0, 110.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("fantasy","advanced","potion_3.png",  "Me_90_A_34_2_vibraphone.wav",   190.0, 204.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("fantasy","advanced","potion_4.png",  "Me_90_A_34_2_whistle.wav",      190.0, 120.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("fantasy","advanced","potion_5.png",  "Me_90_C_34_2_flute.wav",        190.0,  35.0,TANGLE_WIDGET(soundfamily[1]));
+
+	//Harmonic loops
+	create_samplebutton( "fantasy","advanced", "unicorn_1.png", "Ha_90_Dm_34_2_synth.wav",     721.0, 203.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "fantasy","advanced", "unicorn_2.png", "Ha_90_Dm_34_2_guitar.wav",    721.0, 115.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "fantasy","advanced", "unicorn_3.png", "Ha_90_D_34_2_accordion.wav",  621.0, 110.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "fantasy","advanced", "unicorn_4.png", "Ha_90_Am_34_2_elpiano.wav",   545.0, 110.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "fantasy","advanced", "unicorn_5.png", "Ha_90_Am_34_2_cello.wav",     465.0, 95.0,TANGLE_WIDGET(soundfamily[2]));
+
+	//Effect loops
+	create_samplebutton( "fantasy","advanced", "ghost_1.png",  "Fx_90__34_1_vibraslap.wav",   648.0, 26.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "fantasy","advanced", "ghost_2.png",  "Fx_90__34_2_chimes.wav",      450.0,  26.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "fantasy","advanced", "ghost_3.png",  "Fx_90__34_2_gong.wav",        450.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "fantasy","advanced", "ghost_4.png",  "Fx_90_Dm_34_2_crystal.wav",    548.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "fantasy","advanced", "ghost_5.png",  "Fx_90_Dn_34_2_synth.wav",      648.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
+
+	if (variation==1)
+		background_color_code = "rrrrrrrrbbbbbbbbrrrrrrrrbbbbbbbbrrrrrrrr"; //'rhythmic'
+	if (variation==2)
+		background_color_code = "bbbbvvvvbbbbvvvvrrrrbbbbvvvvbbbbvvvvrrrr";  //'strings'
+	if (variation==3)
+		{
+		background_color_code = "vvvvbbbbvvvvbbbbvvvvbbbbllllvvvvvvvv####";  //'synth'
+		disabled_slots_for_end = 4;
+		}
+	}
 	
-	soundfamily[0] = tangle_widget_new(); //TANGLEWIDGET
-	clutter_container_add(CLUTTER_CONTAINER(view), soundfamily[0], NULL);
+	else if (strncmp(name,"animal",6)==0){
+	//Rhythmic loops
+	create_samplebutton( "animal","advanced","monkey_1.png",  "Rh_110__54_1_bongo.wav",      216.0,  20.0,TANGLE_WIDGET(soundfamily[0]));
+	create_samplebutton( "animal","advanced","monkey_2.png",  "Rh_110__54_1_cajon.wav",      296.0,  20.0,TANGLE_WIDGET(soundfamily[0])); 
+	create_samplebutton( "animal","advanced","monkey_3.png",  "Rh_110__54_1_darabouka.wav",  216.0, 103.0,TANGLE_WIDGET(soundfamily[0]));
+	create_samplebutton( "animal","advanced","monkey_4.png",  "Rh_110__54_1_percussion.wav", 396.0,  20.0,TANGLE_WIDGET(soundfamily[0]));
+	create_samplebutton( "animal","advanced","monkey_5.png",  "Rh_110__54_1_tabla.wav",      396.0, 103.0,TANGLE_WIDGET(soundfamily[0]));
 
-	create_samplebutton( "fantasy","140","donkey.png",  "castle_140_drums_2.wav",        296.0, 103.0,TANGLE_WIDGET(soundfamily[0]));
-	create_samplebutton( "fantasy","140","faun.png",    "castle_140_synth_melody_2.wav", 574.0, 233.0,TANGLE_WIDGET(soundfamily[0]));
-	create_samplebutton( "fantasy","140","kangaroo.png","castle_140_synth_riff_2.wav",   626.0, 155.0,TANGLE_WIDGET(soundfamily[0]));
-	create_samplebutton( "fantasy","140","potion.png",  "castle_140_glockenspiel_1.wav", 129.0, 252.0,TANGLE_WIDGET(soundfamily[0]));
-	create_samplebutton( "fantasy","140","snake.png",   "castle_140_synth_glide_4.wav",  332.0, 197.0,TANGLE_WIDGET(soundfamily[0]));
-	create_samplebutton( "fantasy","140","witch.png",   "castle_140_melody_2.wav",       545.0,  31.0,TANGLE_WIDGET(soundfamily[0]));
+	//Melodic loops
+	create_samplebutton("animal","advanced","salamander_1.png",  "Me_110_A_54_1_clarinet.wav",  120.0,  80.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("animal","advanced","salamander_2.png",  "Me_110_C_54_1_flute.wav",      51.0, 110.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("animal","advanced","salamander_3.png",  "Me_110_D_54_1_marimba.wav",   190.0, 204.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("animal","advanced","salamander_4.png",  "Me_110_D_54_1_oud.wav",       190.0, 120.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("animal","advanced","salamander_5.png",  "Me_110_F_54_1_pluck.wav",     190.0,  35.0,TANGLE_WIDGET(soundfamily[1]));
+
+	//Harmonic loops
+	create_samplebutton( "animal","advanced", "dragonfly_1.png", "Ha_110_A_54_1_accordion.wav",  721.0, 203.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "animal","advanced", "dragonfly_3.png", "Ha_110_D_54_1_guitar.wav",     721.0, 115.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "animal","advanced", "dragonfly_2.png", "Ha_110_D_54_1_zither.wav",     651.0, 110.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "animal","advanced", "dragonfly_4.png", "Ha_110_G_54_1_guitar.wav",     605.0, 110.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "animal","advanced", "dragonfly_5.png", "Ha_110_G_54_1_marimba.wav",    575.0, 203.0,TANGLE_WIDGET(soundfamily[2]));
+
+	//Effect loops
+	create_samplebutton( "animal","advanced", "bird_1.png",  "Fx_110__54_1_birdshout.wav",     648.0,  26.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "animal","advanced", "bird_2.png",  "Fx_110__54_1_monkeyshout.wav",   480.0,  26.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "animal","advanced", "bird_3.png",  "Fx_110__54_1_parrot.wav",        480.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "animal","advanced", "bird_4.png",  "Fx_110__54_1_shaker.wav",        548.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "animal","advanced", "bird_5.png",  "Fx_110__54_4_rainstick.wav",     618.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
+
+	if (variation==1)
+		background_color_code = "ggggyyyyvvvvyyyygggggggg##"; //'drumming/percussion'
+	if (variation==2)
+		background_color_code = "rrrrrrrroooooooorrrrrrrr##";  //'flute'
+	if (variation==3)
+		background_color_code = "yyyyggggyyyyggggyyyygggg##";  //'marimba'
+		
+	disabled_slots_for_end = 2; //each variations has same
+	}
 
 
-	ClutterActor *first_menu;
-	first_menu=clutter_texture_new_from_file("/opt/jammo/cross_icon.png", NULL);
-	g_object_set(first_menu, "x", 219.0,  "y", 216.0, NULL);
-	clutter_container_add(CLUTTER_CONTAINER(view), first_menu, NULL);
+	else if (strncmp(name,"city",4)==0){
+	//Rhythmic loops 
+	create_samplebutton( "city","advanced","bucket_1.png",  "Rh_140__44_2_cowbell.wav",      216.0,  20.0,TANGLE_WIDGET(soundfamily[0]));
+	create_samplebutton( "city","advanced","bucket_2.png",  "Rh_140__44_2_eldrums1.wav",     296.0,  20.0,TANGLE_WIDGET(soundfamily[0])); 
+	create_samplebutton( "city","advanced","bucket_3.png",  "Rh_140__44_2_eldrums2.wav",     216.0, 103.0,TANGLE_WIDGET(soundfamily[0]));
+	create_samplebutton( "city","advanced","bucket_4.png",  "Rh_140__44_2_rockdrums1.wav",   396.0,  20.0,TANGLE_WIDGET(soundfamily[0]));
+	create_samplebutton( "city","advanced","bucket_5.png",  "Rh_140__44_2_rockdrums2.wav",   396.0, 103.0,TANGLE_WIDGET(soundfamily[0]));
 
-	clutter_actor_set_reactive(first_menu,TRUE);
-	g_signal_connect (first_menu, "button-press-event", G_CALLBACK (menu_clicked),soundfamily[0]);
-	clutter_actor_hide(soundfamily[0]);
+	//Melodic loops 
+	create_samplebutton("city","advanced","guitar_1.png",  "Me_140_D_44_2_bass2.wav",     120.0,  80.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("city","advanced","guitar_2.png",  "Me_140_D_44_2_guitar2.wav",    51.0, 110.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("city","advanced","guitar_3.png",  "Me_140_F_44_2_guitar1.wav",   190.0, 204.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("city","advanced","guitar_4.png",  "Me_140_F_44_2_synth.wav",     190.0, 120.0,TANGLE_WIDGET(soundfamily[1]));
+	create_samplebutton("city","advanced","guitar_5.png",  "Me_140_G_44_2_bass1.wav",     190.0,  35.0,TANGLE_WIDGET(soundfamily[1]));
 
+	//Harmonic loops 
+	create_samplebutton( "city","advanced", "cycle_5.png", "Ha_140_C_44_2_synth2.wav",      716.0, 203.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "city","advanced", "cycle_3.png", "Ha_140_D_44_2_guitar2.wav",     721.0, 115.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "city","advanced", "cycle_2.png", "Ha_140_D_44_2_organ.wav",       611.0, 120.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "city","advanced", "cycle_4.png", "Ha_140_G_44_2_guitar1.wav",     525.0, 125.0,TANGLE_WIDGET(soundfamily[2]));
+	create_samplebutton( "city","advanced", "cycle_1.png", "Ha_140_G_44_2_synth1.wav",      535.0, 203.0,TANGLE_WIDGET(soundfamily[2]));
 
-	//Second
-	soundfamily[1] = tangle_widget_new();
-	clutter_container_add(CLUTTER_CONTAINER(view), soundfamily[1], NULL);
-	create_samplebutton("fantasy","110","dragon.png","castle_110_clarinet_4.wav",      221.0,  39.0,TANGLE_WIDGET(soundfamily[1]));
-	create_samplebutton("fantasy","110","faerie.png","castle_110_glockenspiel_2.wav",  506.0, 201.0,TANGLE_WIDGET(soundfamily[1]));
-	create_samplebutton("fantasy","110","flower.png","castle_110_piano_2.wav",         631.0, 243.0,TANGLE_WIDGET(soundfamily[1]));
-	create_samplebutton("fantasy","110","ghost.png", "castle_110_flute_2.wav",         548.0,  26.0,TANGLE_WIDGET(soundfamily[1]));
-	create_samplebutton("fantasy","110","owl.png",   "castle_110_owl_2.wav",           627.0, 158.0,TANGLE_WIDGET(soundfamily[1]));
-	create_samplebutton("fantasy","110","wolf.png",  "castle_110_wolf_4.wav",           21.0, 204.0,TANGLE_WIDGET(soundfamily[1]));
-	
-	ClutterActor *second_menu;
-	second_menu=clutter_texture_new_from_file("/opt/jammo/cross_icon.png", NULL);
-	g_object_set(second_menu, "x", 319.0,  "y", 216.0, NULL);
-	clutter_container_add(CLUTTER_CONTAINER(view), second_menu, NULL);
-	clutter_actor_set_reactive(second_menu,TRUE);
-	g_signal_connect (second_menu, "button-press-event", G_CALLBACK (menu_clicked),soundfamily[1]);
-	clutter_actor_hide(soundfamily[1]);
-	
-
-	//Third
-	soundfamily[2] = tangle_widget_new();
-	clutter_container_add(CLUTTER_CONTAINER(view), soundfamily[2], NULL);
-	create_samplebutton( "fantasy","90", "bird.png",    "castle_90_whistle_4.wav",    611.0,  76.0,TANGLE_WIDGET(soundfamily[2]));
-	create_samplebutton( "fantasy","90", "frog.png",    "castle_90_vibraphone_2.wav",  71.0, 245.0,TANGLE_WIDGET(soundfamily[2]));
-	create_samplebutton( "fantasy","90", "specter.png", "castle_90_triangle_4.wav",   217.0,  31.0,TANGLE_WIDGET(soundfamily[2]));
-	create_samplebutton( "fantasy","90", "mermaid.png", "castle_90_chimes_4.wav",     434.0, 274.0,TANGLE_WIDGET(soundfamily[2]));
-	create_samplebutton( "fantasy","90", "prince.png",  "castle_90_brass_2.wav",      628.0, 178.0,TANGLE_WIDGET(soundfamily[2]));
-	create_samplebutton( "fantasy","90", "unicorn.png", "castle_90_oboe_2.wav",       458.0, 101.0,TANGLE_WIDGET(soundfamily[2]));
-
-	ClutterActor *third_menu;
-	third_menu=clutter_texture_new_from_file("/opt/jammo/cross_icon.png", NULL);
-	g_object_set(third_menu, "x", 419.0,  "y", 216.0, NULL);
-	clutter_container_add(CLUTTER_CONTAINER(view), third_menu, NULL);
-	clutter_actor_set_reactive(third_menu,TRUE);
-	g_signal_connect (third_menu, "button-press-event", G_CALLBACK (menu_clicked),soundfamily[2]);
-	clutter_actor_hide(soundfamily[2]);
+	//Effect loops
+	create_samplebutton( "city","advanced", "chopper_1.png",  "Fx_140__44_2_claps.wav",       628.0,  26.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "city","advanced", "chopper_2.png",  "Fx_140_G_44_2_highsynth.wav",  440.0,  26.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "city","advanced", "chopper_3.png",  "Fx_140_G_44_2_robot.wav",      460.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "city","advanced", "chopper_4.png",  "Fx_140_G_44_2_synth.wav",      548.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
+	create_samplebutton( "city","advanced", "chopper_5.png",  "Fx_140_G_44_2_trumpet.wav",    638.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
 
+	if (variation==1)
+		background_color_code = "yyyyrrrryyyyyyyyrrrrrrrryyyyyyyyrrrrrrrr##"; //'drums'
+	if (variation==2)
+		background_color_code = "rrrrrrrrooooyyyyyyyyrrrrrrrryyyyyyyyoooo##";  //'guitar'
+	if (variation==3)
+		background_color_code = "rrrroooorrrroooorrrroooorrrroooorrrroooo##";  //'synth'
+		
+	disabled_slots_for_end = 2; //each variations has same
+	}
+		
+		
+		
+	backing_track_filepath = g_strdup_printf("%s/%s/advanced/backing_track_variation_%d.wav", THEMES_DIR, name,variation);
 	use_two_tracks=TRUE;
 } //advanced game
 
 
 int y_offset =0;
 if (use_two_tracks) y_offset=80;
-	chum_make_sequencer(); //this will make sequencer inside chum
+
+	JammoSequencer* sequencer = jammo_sequencer_new();
+	composing_sequencer = sequencer; //needed when closing composing game
 
 	//Container for tracks (one or two) and backing_track
 	ClutterActor *container_for_tracks = tangle_widget_new();
-	clutter_actor_set_size(container_for_tracks, 2000.0, 120.0+y_offset); //track is 80 and backingtrack is 40
+	
 
 	//Backing track
 	printf("backingtrack filename: '%s'\n",backing_track_filepath);
 	int fd = open(backing_track_filepath,O_RDONLY);
 	if (fd != -1) { //Found it.
-		JammoEditingTrack* backing_track = chum_create_new_empty_track(); //for backing track
+		JammoEditingTrack* backing_track = jammo_editing_track_new();
+		jammo_sequencer_add_track(sequencer, JAMMO_TRACK(backing_track));
 		jammo_editing_track_add_sample(backing_track, jammo_sample_new_from_file(backing_track_filepath), 0);
 		g_free(backing_track_filepath);
 	}
 
 
 	ClutterActor *container_for_backingtrack_blocks = tangle_widget_new();
-	clutter_actor_set_size(container_for_backingtrack_blocks, 2000.0, 40.0);
 	clutter_actor_set_position(container_for_backingtrack_blocks, 0.0, 0.0);
 
 	int number_of_slots = create_backing_track_color_coding(background_color_code,WIDTH_OF_SLOT,y_offset,TANGLE_WIDGET(container_for_backingtrack_blocks));
 	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), container_for_backingtrack_blocks, NULL);
-
-
+	
+	//Tune width of containers
+	clutter_actor_set_size(container_for_backingtrack_blocks,number_of_slots*WIDTH_OF_SLOT, 40.0);
+	clutter_actor_set_size(container_for_tracks,number_of_slots*WIDTH_OF_SLOT, 120.0+y_offset); //track is 80 and backingtrack is 40
+	
+	
 	//Bottom track. Below of this there will be place for scrollbar.
-	JammoEditingTrack* editing_track_theme = chum_create_new_empty_track(); //This new track is automatically putted in sequencer.
+	JammoEditingTrack* editing_track_theme = jammo_editing_track_new();
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme));
 	ClutterActor*	track_view = jammo_track_view_new(editing_track_theme, number_of_slots, 1000000000L, WIDTH_OF_SLOT);
+	g_object_set(track_view, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
 	clutter_actor_set_reactive(track_view, TRUE);
 	g_object_set(track_view, "line-every-nth-slot", 2, NULL);
 	clutter_actor_set_position(track_view, 0.0, 0.0+y_offset);
@@ -608,10 +746,12 @@ if (use_two_tracks) y_offset=80;
 
 	if (use_two_tracks){
 	//Upper track.
-	JammoEditingTrack* editing_track_theme2 = chum_create_new_empty_track(); //This new track is automatically putted in sequencer.
+	JammoEditingTrack* editing_track_theme2 = jammo_editing_track_new();
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme2));
 	ClutterActor*	track_view2 = jammo_track_view_new(editing_track_theme2, number_of_slots, 1000000000L, WIDTH_OF_SLOT);
+	g_object_set(track_view2, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
 	clutter_actor_set_reactive(track_view2, TRUE);
-	g_object_set(track_view2, "line-every-nth-slot", 3, NULL);
+	g_object_set(track_view2, "line-every-nth-slot", 2, NULL);
 	clutter_actor_set_position(track_view2, 0.0, 0.0);
 	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), track_view2, NULL);
 	}
@@ -631,7 +771,7 @@ if (use_two_tracks) y_offset=80;
 	g_object_set(play_button, "x", 0.0,  "y", 195.0, NULL);
 	clutter_container_add(CLUTTER_CONTAINER(view), play_button, NULL);
 	clutter_actor_set_reactive(play_button,TRUE);
-	g_signal_connect (play_button, "button-press-event", G_CALLBACK (on_play_button_clicked),NULL);
+	g_signal_connect (play_button, "button-press-event", G_CALLBACK (on_play_button_clicked),sequencer);
 	
 	/*
 	//Load-button DEBUG
