@@ -64,7 +64,9 @@ int main(int argc, char** argv) {
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
 	
 	track_view = jammo_track_view_new(track, 6, 1000000000L, 100.0);
-	g_object_set(track_view, "line-every-nth-slot", 2, NULL);
+	g_object_set(track_view, "line-every-nth-slot", 2, 
+	             "disabled-slots-begin", 1,
+		     "disabled-slots-end", 1, NULL);
 	clutter_actor_set_position(track_view, 0.0, 200.0);
 	clutter_container_add(CLUTTER_CONTAINER(box), track_view, NULL);
 	
